| Title: | Holistic and Areal Weighted Analysis for Global Development |
|---|---|
| Description: | A professional-grade, multi-'sectoral' platform designed for sub-national monitoring of global development indicators. Optimized for large-scale household surveys including 'DHS', 'MICS', 'MIS', 'IHBS', 'SPA', and 'LSMS', the package provides a comprehensive workflow covering Descriptive, Diagnostic, Predictive, and Prescriptive analytics. Key functionalities include a 'Spatial Equalizer' for seamless data integration, 17 Exploratory Spatial Data Analysis ('ESDA') methods, Small Area Estimation ('SAE') via 'Fay-Herriot' models, Spatial Econometrics ('SAR'/'SEM'), and 4-stage hierarchical multilevel modeling using the 'glmmTMB' engine. It enables researchers and policymakers to identify geographic 'hotspots', quantify spatial inequality ('SDG' 10), and generate publication-ready reports. |
| Authors: | Abdisalam Hassan Muse [aut, cre] (ORCID: <https://orcid.org/0000-0003-4905-0044>) |
| Maintainer: | Abdisalam Hassan Muse <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.3 |
| Built: | 2026-07-24 08:50:00 UTC |
| Source: | https://github.com/abdisalammuse/hawaspatial |
Access files in the current app
app_sys(...)app_sys(...)
... |
character vectors, specifying subdirectory and file(s) |
Read Golem Config
get_golem_config(str, config = Sys.getenv("GOLEM_CONFIG_ACTIVE", "default"))get_golem_config(str, config = Sys.getenv("GOLEM_CONFIG_ACTIVE", "default"))
str |
The setting to read |
config |
The configuration profile |
Run the Shiny Application
run_app( onStart = NULL, options = list(), enableBookmarking = NULL, uiPattern = "/", ... )run_app( onStart = NULL, options = list(), enableBookmarking = NULL, uiPattern = "/", ... )
onStart |
A function that will be called before the app is actually run. |
options |
Named options that should be passed to the 'runApp' call. |
enableBookmarking |
Can be one of "url", "server", or "disable". |
uiPattern |
A regular expression used to match the UI. |
... |
arguments to pass to golem_opts. |